@@ -5,12 +5,12 @@ from functools import partial
 
 class DataApi(object):
     _instance = None
+    http_url = "http://106.53.251.60/app_finance/apidata"
 
     def __init__(self,secret_key,secret_id, timeout=15):
         self._secret_key = secret_key
         self._secret_id = secret_id
         self._timeout = timeout
-        self.http_url = "http://106.53.251.60/app_finance/apidata"
 
     def __new__(cls, *args, **kwargs):
         if cls._instance is None:
