@@ -5,13 +5,21 @@ def wta_api(secret_key,secret_id):
     instance = stock.DataApi(secret_key,secret_id)
     return instance
 
+def set_path(str_path):
+    with open("./path.config","w",encoding="utf-8") as f:
+        f.write(str_path)
 
-def wta_file(RootPath):
+def get_path():
+    with open("./path.config","r",encoding="utf-8") as f:
+        str_path = f.readline()
+    return str_path
+
+def get_mainClass():
     '''
     :param RootPath: 数据路径
     :return:
     '''
-    instance = filedata_source_process.MianClass(RootPath)
+    instance = filedata_source_process.MainClass(get_path())
     return instance
 
 
